# -*- coding: utf-8 -*-
"""
Copyright (c) 2015 Red Hat, Inc
All rights reserved.

This software may be modified and distributed under the terms
of the BSD license. See the LICENSE file for details.
"""
DOCKERFILE_FILENAME = 'Dockerfile'
COMMENT_INSTRUCTION = 'COMMENT'
